Interface: BarOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: BarOptions

## # Hierarchy

- `Omit`<`CommonElementOptions`, `"borderWidth"`>

  ↳ `BarOptions`

## # Properties

### # backgroundColor

• backgroundColor: `Color`

#### # Inherited from

Omit.backgroundColor

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # base

• base: `number`

The base value for the bar in data units along the value axis.

#### # Defined in

index.esm.d.ts:1990
(opens new window)

### # borderColor

• borderColor: `Color`

#### # Inherited from

Omit.borderColor

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderRadius

• borderRadius: `number` | `BorderRadius`

Border radius

`default` 0

#### # Defined in

index.esm.d.ts:2002
(opens new window)

### # borderSkipped

• borderSkipped: `boolean` | `"start"` | `"end"` | `"left"` | `"right"` | `"bottom"` | `"top"` | `"middle"`

Skipped (excluded) border: 'start', 'end', 'left', 'right', 'bottom', 'top', 'middle', false (none) or true (all).

`default` 'start'

#### # Defined in

index.esm.d.ts:1996
(opens new window)

### # borderWidth

• borderWidth: `number` | { `bottom?`: `number` ; `left?`: `number` ; `right?`: `number` ; `top?`: `number` }

Width of the border, number for all sides, object to specify width for each side specifically

`default` 0

#### # Defined in

index.esm.d.ts:2015
(opens new window)

### # inflateAmount

• inflateAmount: `number` | `"auto"`

Amount to inflate the rectangle(s). This can be used to hide artifacts between bars. Unit is pixels. 'auto' translates to 0.33 pixels when barPercentage * categoryPercentage is 1, else 0.

`default` 'auto'

#### # Defined in

index.esm.d.ts:2009
(opens new window)